==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/StaticSiteLinkedBackendArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.azurenative.web.StaticSiteLinkedBackendArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Static Site Linked Backend ARM resource.
 * Azure REST API version: 2022-09-01. Prior API version in Azure Native 1.x: 2022-03-01.
 * Other available API versions: 2023-01-01.
 * ## Example Usage
 * ### Link a backend to a static site
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var staticSiteLinkedBackend = new AzureNative.Web.StaticSiteLinkedBackend("staticSiteLinkedBackend", new()
 *     {
 *         BackendResourceId = "/subscription/34adfa4f-cedf-4dc0-ba29-b6d1a69ab345/resourceGroups/backendRg/providers/Microsoft.Web/sites/testBackend",
 *         LinkedBackendName = "testBackend",
 *         Name = "testStaticSite0",
 *         Region = "West US 2",
 *         ResourceGroupName = "rg",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/web/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := web.NewStaticSiteLinkedBackend(ctx, "staticSiteLinkedBackend", &web.StaticSiteLinkedBackendArgs{
 * 			BackendResourceId: pulumi.String("/subscription/34adfa4f-cedf-4dc0-ba29-b6d1a69ab345/resourceGroups/backendRg/providers/Microsoft.Web/sites/testBackend"),
 * 			LinkedBackendName: pulumi.String("testBackend"),
 * 			Name:              pulumi.String("testStaticSite0"),
 * 			Region:            pulumi.String("West US 2"),
 * 			ResourceGroupName: pulumi.String("rg"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.web.StaticSiteLinkedBackend;
 * import com.pulumi.azurenative.web.StaticSiteLinkedBackendArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var staticSiteLinkedBackend = new StaticSiteLinkedBackend("staticSiteLinkedBackend", StaticSiteLinkedBackendArgs.builder()
 *             .backendResourceId("/subscription/34adfa4f-cedf-4dc0-ba29-b6d1a69ab345/resourceGroups/backendRg/providers/Microsoft.Web/sites/testBackend")
 *             .linkedBackendName("testBackend")
 *             .name("testStaticSite0")
 *             .region("West US 2")
 *             .resourceGroupName("rg")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:StaticSiteLinkedBackend testBackend /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/staticSites/{name}/linkedBackends/{linkedBackendName}
 * ```
 * @property backendResourceId The resource id of the backend linked to the static site
 * @property kind Kind of resource.
 * @property linkedBackendName Name of the backend to link to the static site
 * @property name Name of the static site
 * @property region The region of the backend linked to the static site
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 */
public data class StaticSiteLinkedBackendArgs(
    public val backendResourceId: Output<String>? = null,
    public val kind: Output<String>? = null,
    public val linkedBackendName: Output<String>? = null,
    public val name: Output<String>? = null,
    public val region: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.StaticSiteLinkedBackendArgs> {
    override fun toJava(): com.pulumi.azurenative.web.StaticSiteLinkedBackendArgs =
        com.pulumi.azurenative.web.StaticSiteLinkedBackendArgs.builder()
            .backendResourceId(backendResourceId?.applyValue({ args0 -> args0 }))
            .kind(kind?.applyValue({ args0 -> args0 }))
            .linkedBackendName(linkedBackendName?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .region(region?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [StaticSiteLinkedBackendArgs].
 */
@PulumiTagMarker
public class StaticSiteLinkedBackendArgsBuilder internal constructor() {
    private var backendResourceId: Output<String>? = null

    private var kind: Output<String>? = null

    private var linkedBackendName: Output<String>? = null

    private var name: Output<String>? = null

    private var region: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    /**
     * @param value The resource id of the backend linked to the static site
     */
    @JvmName("mapcpoputeynoyhv")
    public suspend fun backendResourceId(`value`: Output<String>) {
        this.backendResourceId = value
    }

    /**
     * @param value Kind of resource.
     */
    @JvmName("mrleiknkggghvfcd")
    public suspend fun kind(`value`: Output<String>) {
        this.kind = value
    }

    /**
     * @param value Name of the backend to link to the static site
     */
    @JvmName("wcplubtjrfbgfctf")
    public suspend fun linkedBackendName(`value`: Output<String>) {
        this.linkedBackendName = value
    }

    /**
     * @param value Name of the static site
     */
    @JvmName("trhbumfulluytooh")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The region of the backend linked to the static site
     */
    @JvmName("ujsejtjepuxedbqm")
    public suspend fun region(`value`: Output<String>) {
        this.region = value
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("dvmybxyjqodaifnd")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The resource id of the backend linked to the static site
     */
    @JvmName("xdfaxsltqcmjoiqj")
    public suspend fun backendResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backendResourceId = mapped
    }

    /**
     * @param value Kind of resource.
     */
    @JvmName("dhkarxkneadotxcn")
    public suspend fun kind(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Name of the backend to link to the static site
     */
    @JvmName("rdkpphjibhqfhcrk")
    public suspend fun linkedBackendName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.linkedBackendName = mapped
    }

    /**
     * @param value Name of the static site
     */
    @JvmName("bxbiitoamdtpibbw")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The region of the backend linked to the static site
     */
    @JvmName("abesxmapxxhefyea")
    public suspend fun region(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.region = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("svhcpaknxkejmufy")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    internal fun build(): StaticSiteLinkedBackendArgs = StaticSiteLinkedBackendArgs(
        backendResourceId = backendResourceId,
        kind = kind,
        linkedBackendName = linkedBackendName,
        name = name,
        region = region,
        resourceGroupName = resourceGroupName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/StaticSiteLinkedBackendArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.azurenative.web.StaticSiteLinkedBackendArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Static Site Linked Backend ARM resource.
 * Azure REST API version: 2022-09-01. Prior API version in Azure Native 1.x: 2022-03-01.
 * Other available API versions: 2023-01-01.
 * ## Example Usage
 * ### Link a backend to a static site
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var staticSiteLinkedBackend = new AzureNative.Web.StaticSiteLinkedBackend("staticSiteLinkedBackend", new()
 *     {
 *         BackendResourceId = "/subscription/34adfa4f-cedf-4dc0-ba29-b6d1a69ab345/resourceGroups/backendRg/providers/Microsoft.Web/sites/testBackend",
 *         LinkedBackendName = "testBackend",
 *         Name = "testStaticSite0",
 *         Region = "West US 2",
 *         ResourceGroupName = "rg",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/web/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := web.NewStaticSiteLinkedBackend(ctx, "staticSiteLinkedBackend", &web.StaticSiteLinkedBackendArgs{
 * 			BackendResourceId: pulumi.String("/subscription/34adfa4f-cedf-4dc0-ba29-b6d1a69ab345/resourceGroups/backendRg/providers/Microsoft.Web/sites/testBackend"),
 * 			LinkedBackendName: pulumi.String("testBackend"),
 * 			Name:              pulumi.String("testStaticSite0"),
 * 			Region:            pulumi.String("West US 2"),
 * 			ResourceGroupName: pulumi.String("rg"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.web.StaticSiteLinkedBackend;
 * import com.pulumi.azurenative.web.StaticSiteLinkedBackendArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var staticSiteLinkedBackend = new StaticSiteLinkedBackend("staticSiteLinkedBackend", StaticSiteLinkedBackendArgs.builder()
 *             .backendResourceId("/subscription/34adfa4f-cedf-4dc0-ba29-b6d1a69ab345/resourceGroups/backendRg/providers/Microsoft.Web/sites/testBackend")
 *             .linkedBackendName("testBackend")
 *             .name("testStaticSite0")
 *             .region("West US 2")
 *             .resourceGroupName("rg")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:StaticSiteLinkedBackend testBackend /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/staticSites/{name}/linkedBackends/{linkedBackendName}
 * ```
 * @property backendResourceId The resource id of the backend linked to the static site
 * @property kind Kind of resource.
 * @property linkedBackendName Name of the backend to link to the static site
 * @property name Name of the static site
 * @property region The region of the backend linked to the static site
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 */
public data class StaticSiteLinkedBackendArgs(
    public val backendResourceId: Output<String>? = null,
    public val kind: Output<String>? = null,
    public val linkedBackendName: Output<String>? = null,
    public val name: Output<String>? = null,
    public val region: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.StaticSiteLinkedBackendArgs> {
    override fun toJava(): com.pulumi.azurenative.web.StaticSiteLinkedBackendArgs =
        com.pulumi.azurenative.web.StaticSiteLinkedBackendArgs.builder()
            .backendResourceId(backendResourceId?.applyValue({ args0 -> args0 }))
            .kind(kind?.applyValue({ args0 -> args0 }))
            .linkedBackendName(linkedBackendName?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .region(region?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [StaticSiteLinkedBackendArgs].
 */
@PulumiTagMarker
public class StaticSiteLinkedBackendArgsBuilder internal constructor() {
    private var backendResourceId: Output<String>? = null

    private var kind: Output<String>? = null

    private var linkedBackendName: Output<String>? = null

    private var name: Output<String>? = null

    private var region: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    /**
     * @param value The resource id of the backend linked to the static site
     */
    @JvmName("vicmnnuipbakukui")
    public suspend fun backendResourceId(`value`: Output<String>) {
        this.backendResourceId = value
    }

    /**
     * @param value Kind of resource.
     */
    @JvmName("jslvfdjmqfhqoqqp")
    public suspend fun kind(`value`: Output<String>) {
        this.kind = value
    }

    /**
     * @param value Name of the backend to link to the static site
     */
    @JvmName("iejajqfeohoqablf")
    public suspend fun linkedBackendName(`value`: Output<String>) {
        this.linkedBackendName = value
    }

    /**
     * @param value Name of the static site
     */
    @JvmName("mechfuotwkygjigf")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The region of the backend linked to the static site
     */
    @JvmName("amnysbdffaxcdixp")
    public suspend fun region(`value`: Output<String>) {
        this.region = value
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("ktpodqwcohgasnpt")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The resource id of the backend linked to the static site
     */
    @JvmName("ldkglikunvfkqthj")
    public suspend fun backendResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backendResourceId = mapped
    }

    /**
     * @param value Kind of resource.
     */
    @JvmName("sfpyfuftnlqmajgd")
    public suspend fun kind(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Name of the backend to link to the static site
     */
    @JvmName("pugsajkjlrovlsnr")
    public suspend fun linkedBackendName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.linkedBackendName = mapped
    }

    /**
     * @param value Name of the static site
     */
    @JvmName("lulvlqrjcpdukemp")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The region of the backend linked to the static site
     */
    @JvmName("nwxqeqsedxmnfcxj")
    public suspend fun region(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.region = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("yytrdaskqrvqalev")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    internal fun build(): StaticSiteLinkedBackendArgs = StaticSiteLinkedBackendArgs(
        backendResourceId = backendResourceId,
        kind = kind,
        linkedBackendName = linkedBackendName,
        name = name,
        region = region,
        resourceGroupName = resourceGroupName,
    )
}
